# Cascadia


**A transformer model for de novo sequencing of data-independent acquisition mass spectrometry data**

![image](docs/source/cascadia-graphical-abstract.png)

If you use Cascadia in your work, please cite the following publication:

Sanders, Justin, et al. ‘A Transformer Model for de Novo Sequencing of Data-Independent Acquisition Mass Spectrometry Data’. bioRxiv, Cold Spring Harbor Laboratory, 2024, [https://doi.org/10.1101/2024.06.03.597251](https://doi.org/10.1101/2024.06.03.597251).

## Documentation

Documentation for Cascadia is avaialable at:
[https://cascadia.readthedocs.io/en/latest/index.html](https://cascadia.readthedocs.io/en/latest/index.html)
